%%
%% This is file `numodel-NL.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% numodel.dtx  (with options: `NL')
%% 
%% This is a generated file.
%% 
%% Copyright (C) 2026 Paul Zuurbier <mail@paulzuurbier.nl>
%% 
%% This work may be distributed and/or modified under the conditions
%% of the LaTeX Project Public License, either version 1.3c of this
%% license or (at your option) any later version.  The latest version
%% of this license is in https://www.latex-project.org/lppl.txt
%% 
%% This work has the LPPL maintenance status 'maintained'.
%% The Current Maintainer of this work is Paul Zuurbier.
%% 
%% This work consists of the files numodel.dtx and numodel.ins, the
%% derived files numodel.sty, numodel-EN.def and numodel-NL.def, and the
%% companion Lua module numodel.lua.
%% 
\ProvidesExplFile{numodel-NL.def}{2026/05/30}{0.7.0}
  {numodel~keyword~table~--~Dutch~(CoachTaal)}
\cs_new:Npn \__numodel_kw_NL_if:           { Als~ }
\cs_new:Npn \__numodel_kw_NL_then:         { ~Dan~ }
\cs_new:Npn \__numodel_kw_NL_then_nl:      { ~Dan }
\cs_new:Npn \__numodel_kw_NL_else:         { ~Anders~ }
\cs_new:Npn \__numodel_kw_NL_else_nl:      { Anders }
\cs_new:Npn \__numodel_kw_NL_endif:        { ~EindAls }
\cs_new:Npn \__numodel_kw_NL_endif_nl:     { EindAls }
\cs_new:Npn \__numodel_kw_NL_and:          { ~EN~ }
\cs_new:Npn \__numodel_kw_NL_or:           { ~OF~ }
\cs_new:Npn \__numodel_kw_NL_not:          { NIET~ }
\cs_new:Npn \__numodel_kw_NL_sign:         { Teken }
\cs_new:Npn \__numodel_kw_NL_abs:          { Abs }
\cs_new:Npn \__numodel_kw_NL_sqrt:         { Sqrt }
\cs_new:Npn \__numodel_kw_NL_exp:          { Exp }
\cs_new:Npn \__numodel_kw_NL_ln:           { Ln }
\cs_new:Npn \__numodel_kw_NL_sin:          { Sin }
\cs_new:Npn \__numodel_kw_NL_cos:          { Cos }
\cs_new:Npn \__numodel_kw_NL_tan:          { Tan }
\cs_new:Npn \__numodel_kw_NL_asin:         { Arcsin }
\cs_new:Npn \__numodel_kw_NL_acos:         { Arccos }
\cs_new:Npn \__numodel_kw_NL_atan:         { Arctan }
\cs_new:Npn \__numodel_kw_NL_min:          { Min }
\cs_new:Npn \__numodel_kw_NL_max:          { Max }
\cs_new:Npn \__numodel_kw_NL_floor:        { Entier }
\cs_new:Npn \__numodel_kw_NL_stop:         { ~Stop~ }
\cs_new:Npn \__numodel_kw_NL_th_model:     { model }
\cs_new:Npn \__numodel_kw_NL_th_initvals:  { startwaarden }
\cs_new:Npn \__numodel_kw_NL_contfoot:     { Wordt~vervolgd~op~volgende~pagina }
\cs_new:Npn \__numodel_kw_NL_conthead:     { (Vervolg) }
\cs_new:Npn \__numodel_kw_NL_dsep_default: { comma }
\endinput
%%
%% End of file `numodel-NL.def'.
