%%
%% This is file `numodel-EN.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% numodel.dtx  (with options: `EN')
%% 
%% This is a generated file.
%% 
%% Copyright (C) 2026 Paul Zuurbier <mail@paulzuurbier.nl>
%% 
%% This work may be distributed and/or modified under the conditions
%% of the LaTeX Project Public License, either version 1.3c of this
%% license or (at your option) any later version.  The latest version
%% of this license is in https://www.latex-project.org/lppl.txt
%% 
%% This work has the LPPL maintenance status 'maintained'.
%% The Current Maintainer of this work is Paul Zuurbier.
%% 
%% This work consists of the files numodel.dtx and numodel.ins, the
%% derived files numodel.sty, numodel-EN.def and numodel-NL.def, and the
%% companion Lua module numodel.lua.
%% 
\ProvidesExplFile{numodel-EN.def}{2026/05/30}{0.7.0}
  {numodel~keyword~table~--~English~(XMILE)}
\cs_new:Npn \__numodel_kw_EN_if:           { IF~ }
\cs_new:Npn \__numodel_kw_EN_then:         { ~THEN~ }
\cs_new:Npn \__numodel_kw_EN_then_nl:      { ~THEN }
\cs_new:Npn \__numodel_kw_EN_else:         { ~ELSE~ }
\cs_new:Npn \__numodel_kw_EN_else_nl:      { ELSE }
\cs_new:Npn \__numodel_kw_EN_endif:        { ~ENDIF }
\cs_new:Npn \__numodel_kw_EN_endif_nl:     { ENDIF }
\cs_new:Npn \__numodel_kw_EN_and:          { ~AND~ }
\cs_new:Npn \__numodel_kw_EN_or:           { ~OR~ }
\cs_new:Npn \__numodel_kw_EN_not:          { NOT~ }
\cs_new:Npn \__numodel_kw_EN_sign:         { SIGN }
\cs_new:Npn \__numodel_kw_EN_abs:          { ABS }
\cs_new:Npn \__numodel_kw_EN_sqrt:         { SQRT }
\cs_new:Npn \__numodel_kw_EN_exp:          { EXP }
\cs_new:Npn \__numodel_kw_EN_ln:           { LN }
\cs_new:Npn \__numodel_kw_EN_sin:          { SIN }
\cs_new:Npn \__numodel_kw_EN_cos:          { COS }
\cs_new:Npn \__numodel_kw_EN_tan:          { TAN }
\cs_new:Npn \__numodel_kw_EN_asin:         { ARCSIN }
\cs_new:Npn \__numodel_kw_EN_acos:         { ARCCOS }
\cs_new:Npn \__numodel_kw_EN_atan:         { ARCTAN }
\cs_new:Npn \__numodel_kw_EN_min:          { MIN }
\cs_new:Npn \__numodel_kw_EN_max:          { MAX }
\cs_new:Npn \__numodel_kw_EN_floor:        { INT }
\cs_new:Npn \__numodel_kw_EN_stop:         { ~STOP~ }
\cs_new:Npn \__numodel_kw_EN_th_model:     { model }
\cs_new:Npn \__numodel_kw_EN_th_initvals:  { initial~values }
\cs_new:Npn \__numodel_kw_EN_contfoot:     { Continued~on~next~page }
\cs_new:Npn \__numodel_kw_EN_conthead:     { (Continued) }
\cs_new:Npn \__numodel_kw_EN_dsep_default: { point }
\endinput
%%
%% End of file `numodel-EN.def'.
